pub struct Execution {
pub globals: Vec<Value>,
pub stack: Vec<Value>,
pub uv: Value,
pub color: Value,
pub roughness: Value,
pub metallic: Value,
pub emissive: Value,
pub opacity: Value,
pub bump: Value,
pub normal: Value,
pub hitpoint: Value,
pub time: Value,
/* private fields */
}Fields
globals: Vec<Value>Global variables. The parser keeps count of all global variables and we allocate the array on creation.
stack: Vec<Value>The execution stack.
uv: ValueUV
color: ValueInput/Output color
roughness: ValueRoughness
metallic: ValueMetallic
emissive: ValueEmissive
opacity: ValueOpacity
bump: ValueBump
normal: ValueNormal
hitpoint: ValueHitpoint
time: ValueTime
Implementations
Sourceimpl Execution
impl Execution
pub fn new(var_size: usize) -> Self
pub fn new_from_var(execution: &Execution) -> Self
Sourcepub fn reset(&mut self, var_size: usize)
pub fn reset(&mut self, var_size: usize)
When switching between programs we need to resize the count of global variables.
pub fn execute( &mut self, code: &[NodeOp], program: &Program, palette: &ThePalette, )
Sourcepub fn shade(&mut self, index: usize, program: &Program, palette: &ThePalette)
pub fn shade(&mut self, index: usize, program: &Program, palette: &ThePalette)
Execute the shading function
Sourcepub fn execute_function_no_args(
&mut self,
index: usize,
program: &Program,
palette: &ThePalette,
) -> Value
pub fn execute_function_no_args( &mut self, index: usize, program: &Program, palette: &ThePalette, ) -> Value
Call a function with no arguments
Sourcepub fn execute_function(
&mut self,
args: &[Value],
index: usize,
program: &Program,
palette: &ThePalette,
) -> Value
pub fn execute_function( &mut self, args: &[Value], index: usize, program: &Program, palette: &ThePalette, ) -> Value
Call a function with arguments provided as a slice.