pub struct Parser { /* private fields */ }Implementations
Sourceimpl Parser
impl Parser
pub fn new() -> Self
Sourcepub fn compile(&mut self, path: PathBuf) -> Result<Module, ParseError>
pub fn compile(&mut self, path: PathBuf) -> Result<Module, ParseError>
Compile the main source module.
Sourcepub fn compile_module(
&mut self,
name: String,
source: String,
path: PathBuf,
) -> Result<Module, ParseError>
pub fn compile_module( &mut self, name: String, source: String, path: PathBuf, ) -> Result<Module, ParseError>
Compile a module with the given name, source code, and path.
Sourcepub fn get_swizzle_at_current(&mut self) -> Vec<u8> ⓘ
pub fn get_swizzle_at_current(&mut self) -> Vec<u8> ⓘ
Returns the swizzle at the current token if any.
Sourcepub fn is_swizzle_valid_at_current(&self) -> bool
pub fn is_swizzle_valid_at_current(&self) -> bool
Returns true if a swizzle is valid at the current token.